@@ -1,4 +1,10 @@
 from __init__ import *
+import numpy as np
+import matplotlib.pyplot as plt
+import seaborn as sns
+from pylab import mpl
+mpl.rcParams['font.sans-serif']=['SimHei']
+sns.set()
 from bisect import bisect_left
 
 class gradeEvaluation():
